package TestGC;

use Catalyst::Runtime 5.70;
use parent 'Catalyst';

__PACKAGE__->setup;

1;
